GiteeClient

Struct GiteeClient 

pub struct GiteeClient { /* private fields */ }
Gitee API Client

Implementations

Source

impl GiteeClient

pub async fn get_authenticated_user(&self) -> Result<User, GiteeError>

Get authenticated user information (current user)

pub async fn get_user_info(&self, username: &str) -> Result<User, GiteeError>

Get user information by username

pub async fn search_users( &self, query: &str, ) -> Result<Vec<SearchUserResult>, GiteeError>

Search users

Source

impl GiteeClient

pub async fn get_repo( &self, owner: &str, repo: &str, ) -> Result<Repository, GiteeError>

Get repository information

pub async fn create_user_repo( &self, name: &str, description: Option<&str>, private: bool, ) -> Result<Repository, GiteeError>

Create a new user repository

pub async fn create_org_repo( &self, org: &str, name: &str, description: Option<&str>, private: bool, ) -> Result<Repository, GiteeError>

Create a new organization repository

pub async fn create_enterprise_repo( &self, enterprise: &str, name: &str, description: Option<&str>, private: bool, ) -> Result<Repository, GiteeError>

Create a new enterprise repository

pub async fn list_user_repos(&self) -> Result<Vec<Repository>, GiteeError>

List user repositories

pub async fn fork_repository( &self, owner: &str, repo: &str, ) -> Result<Repository, GiteeError>

Fork a repository

pub async fn search_repositories( &self, query: &str, from: Option<i32>, size: Option<i32>, sort: Option<&str>, ) -> Result<Vec<Repository>, GiteeError>

Search repositories (Open source)

pub async fn delete_repo( &self, owner: &str, repo: &str, ) -> Result<(), GiteeError>

Delete a repository

pub async fn star_repo(&self, owner: &str, repo: &str) -> Result<(), GiteeError>

Star a repository

pub async fn unstar_repo( &self, owner: &str, repo: &str, ) -> Result<(), GiteeError>

Unstar a repository

pub async fn watch_repo( &self, owner: &str, repo: &str, ) -> Result<(), GiteeError>

Watch a repository

pub async fn unwatch_repo( &self, owner: &str, repo: &str, ) -> Result<(), GiteeError>

Unwatch a repository

Source

impl GiteeClient

pub async fn list_issues( &self, options: Option<IssueListOptions>, ) -> Result<Vec<Issue>, GiteeError>

List all issues

pub async fn list_repo_issues( &self, owner: &str, repo: &str, options: Option<IssueListOptions>, ) -> Result<Vec<Issue>, GiteeError>

List repository issues

pub async fn create_issue( &self, repo_owner: &str, repo_name: &str, title: &str, body: Option<&str>, ) -> Result<Issue, GiteeError>

Create a new issue

pub async fn close_issue( &self, repo_owner: &str, repo_name: &str, issue_number: &str, ) -> Result<Issue, GiteeError>

Close an issue by setting its state to “closed”

pub async fn update_issue( &self, owner: &str, repo: &str, number: &str, title: Option<&str>, body: Option<&str>, state: Option<&str>, ) -> Result<Issue, GiteeError>

Update an issue

pub async fn get_issue_detail( &self, owner: &str, repo: &str, number: &str, ) -> Result<Issue, GiteeError>

Get issue detail

pub async fn comment_issue( &self, owner: &str, repo: &str, number: &str, body: &str, ) -> Result<Comment, GiteeError>

Comment on an issue

pub async fn list_issue_comments( &self, owner: &str, repo: &str, number: &str, ) -> Result<Vec<Comment>, GiteeError>

List issue comments

pub async fn list_repo_milestones( &self, owner: &str, repo: &str, state: Option<&str>, ) -> Result<Vec<Milestone>, GiteeError>

List repository milestones

pub async fn create_milestone( &self, owner: &str, repo: &str, title: &str, description: Option<&str>, due_on: Option<&str>, ) -> Result<Milestone, GiteeError>

Create a new milestone

pub async fn get_milestone( &self, owner: &str, repo: &str, number: i32, ) -> Result<Milestone, GiteeError>

Get a milestone by number

pub async fn update_milestone( &self, owner: &str, repo: &str, number: i32, title: Option<&str>, description: Option<&str>, state: Option<&str>, ) -> Result<Milestone, GiteeError>

Update a milestone

pub async fn delete_milestone( &self, owner: &str, repo: &str, number: i32, ) -> Result<(), GiteeError>

Delete a milestone

Source

impl GiteeClient

pub async fn list_pulls( &self, owner: &str, repo: &str, options: Option<PullListOptions>, ) -> Result<Vec<PullRequest>, GiteeError>

List all pull requests for a repository

pub async fn create_pull( &self, owner: &str, repo: &str, title: &str, head: &str, base: &str, body: Option<&str>, ) -> Result<PullRequest, GiteeError>

Create a new pull request

pub async fn close_pull( &self, owner: &str, repo: &str, pull_number: &str, ) -> Result<PullRequest, GiteeError>

Close a pull request by setting its state to “closed”

pub async fn merge_pull( &self, owner: &str, repo: &str, pull_number: &str, ) -> Result<PullRequest, GiteeError>

Merge a pull request

pub async fn get_pull_detail( &self, owner: &str, repo: &str, number: &str, ) -> Result<PullRequest, GiteeError>

Get pull request detail

pub async fn update_pull( &self, owner: &str, repo: &str, number: &str, title: Option<&str>, body: Option<&str>, state: Option<&str>, ) -> Result<PullRequest, GiteeError>

Update a pull request

pub async fn comment_pull( &self, owner: &str, repo: &str, number: &str, body: &str, ) -> Result<Comment, GiteeError>

Comment on a pull request

pub async fn list_pull_comments( &self, owner: &str, repo: &str, number: &str, ) -> Result<Vec<Comment>, GiteeError>

List pull request comments

pub async fn get_diff_files( &self, owner: &str, repo: &str, number: &str, ) -> Result<Vec<FileDiff>, GiteeError>

Get diff files for a pull request

Source

impl GiteeClient

pub async fn list_labels( &self, owner: &str, repo: &str, ) -> Result<Vec<Label>, GiteeError>

List all labels in a repository

pub async fn create_label( &self, owner: &str, repo: &str, name: &str, color: &str, description: Option<&str>, ) -> Result<Label, GiteeError>

Create a new label in a repository

pub async fn update_label( &self, owner: &str, repo: &str, name: &str, new_name: Option<&str>, color: Option<&str>, description: Option<&str>, ) -> Result<Label, GiteeError>

Update a label in a repository

pub async fn delete_label( &self, owner: &str, repo: &str, name: &str, ) -> Result<(), GiteeError>

Delete a label from a repository

Source

impl GiteeClient

pub async fn get_file_content( &self, owner: &str, repo: &str, file_path: &str, ref: Option<&str>, ) -> Result<FileContent, GiteeError>

Get file content

pub async fn list_repo_files( &self, owner: &str, repo: &str, path: Option<&str>, ref: Option<&str>, ) -> Result<Vec<RepoFile>, GiteeError>

List repository files

pub async fn search_files_by_content( &self, query: &str, owner: Option<&str>, repo: Option<&str>, page: Option<i32>, per_page: Option<i32>, ) -> Result<Vec<RepoFile>, GiteeError>

Search files by content

Source

impl GiteeClient

pub async fn list_user_notifications( &self, ) -> Result<Vec<Notification>, GiteeError>

List user notifications

Source

impl GiteeClient

pub async fn create_release( &self, owner: &str, repo: &str, tag_name: &str, name: &str, body: Option<&str>, ) -> Result<Release, GiteeError>

Create a release

pub async fn list_releases( &self, owner: &str, repo: &str, ) -> Result<Vec<Release>, GiteeError>

List releases

Source

impl GiteeClient

pub async fn list_repo_wikis( &self, owner: &str, repo: &str, ) -> Result<Vec<WikiPage>, GiteeError>

List all wiki pages for a repository by cloning it locally

pub async fn get_repo_wiki( &self, owner: &str, repo: &str, slug: &str, ) -> Result<WikiPage, GiteeError>

Get a single wiki page content

pub async fn create_repo_wiki( &self, owner: &str, repo: &str, title: &str, body: &str, ) -> Result<WikiPage, GiteeError>

Create or Update a wiki page

pub async fn update_repo_wiki( &self, owner: &str, repo: &str, _slug: &str, title: &str, body: &str, ) -> Result<WikiPage, GiteeError>

Update a wiki page (alias to create_repo_wiki)

pub async fn delete_repo_wiki( &self, owner: &str, repo: &str, slug: &str, ) -> Result<(), GiteeError>

Delete a wiki page

Source

impl GiteeClient

pub fn new( token: Option<String>, base_url: Option<String>, ) -> Result<Self, GiteeError>

Creates a new GiteeClient instance

pub fn client(&self) -> &Client

Get the HTTP client

pub fn base_url(&self) -> &str

Get the API base URL

pub fn token(&self) -> &str

Get the authentication token

pub fn auth_header(&self) -> String

Build authorization header value